@@ -40,7 +40,6 @@ def test_elsewhere_in_the_path(console_script, script_runner):
 
 @pytest.mark.script_launch_mode('both')
 def test_run_pytest(tmpdir, console_script, script_runner, launch_mode):
-    # TODO: check if same process or not!
     console_script.write('import os;print(os.getpid())')
     test = tmpdir.join('test_{}.py'.format(launch_mode))
     compare = '==' if launch_mode == 'inprocess' else '!='
@@ -208,3 +207,62 @@ def test_fail(script_runner):
         assert '# Running console script' not in result.stdout
         assert '12345' not in result.stdout
         assert '54321' not in result.stdout
+
+
+@pytest.mark.script_launch_mode('inprocess')
+def test_mocking(console_script, script_runner, monkeypatch):
+    """Test mocking in of console scripts (in-process mode only).
+
+    Note: we can't mock objects in the script itself because it will not be
+    imported via normal import system but we can mock anything in the modules
+    that the script imports.
+
+    """
+    console_script.write(
+        """
+import os
+print(os.path.basename('foo'))
+        """
+    )
+    monkeypatch.setattr(os.path, 'basename', lambda foo: 'bar')
+    result = script_runner.run(str(console_script))
+    assert result.success
+    assert result.stdout == 'bar\n'
+
+
+def test_hide_run_result_arg(tmpdir, console_script, script_runner):
+    """Disable printing of the RunResult to stdout with print_result=False."""
+    console_script.write('print("the answer is 42")')
+    test = tmpdir.join('test_hrra.py')
+    test.write(
+        """
+import pytest
+
+@pytest.mark.script_launch_mode('both')
+def test_script(script_runner):
+    script_runner.run('{}', print_result=False)
+        """.format(console_script)
+    )
+    result = script_runner.run('pytest', '-s', str(test))
+    assert result.success
+    assert 'the answer is 42' not in result.stdout
+    assert 'Running console script' not in result.stdout
+
+
+def test_hide_run_result_opt(tmpdir, console_script, script_runner):
+    """Disable printing of the RunResult to stdout with print_result=False."""
+    console_script.write('print("the answer is 42")')
+    test = tmpdir.join('test_hrro.py')
+    test.write(
+        """
+import pytest
+
+@pytest.mark.script_launch_mode('both')
+def test_script(script_runner):
+    script_runner.run('{}')
+        """.format(console_script)
+    )
+    result = script_runner.run('pytest', '-s', '--hide-run-results', str(test))
+    assert result.success
+    assert 'the answer is 42' not in result.stdout
+    assert 'Running console script' not in result.stdout
